# DHV ChangeLog

## v0.4.0

**Released: 2025-07-16**

- Added a command to set the theme for the code editor panel.
  ([#12](https://github.com/davep/dhv/pull/12))
- Added support for jumping to the AST documentation from the AST panel.
  ([#13](https://github.com/davep/dhv/pull/13))

## v0.3.0

**Released: 2025-07-12**

- Added support for viewing the AST of the Python code.
  ([#8](https://github.com/davep/dhv/pull/8))

## v0.2.0

**Released: 2025-07-09**

- Added the ability to pass a filename on the command line.
  ([#5](https://github.com/davep/dhv/pull/5))

## v0.1.1

**Released: 2025-07-08**

- Initial release.

## v0.1.0

**Released: 2025-07-01**

- Initial placeholder package to test that the name is available in PyPI.

[//]: # (ChangeLog.md ends here)
